# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.feature_store.v1.internal.data_source import data_source_service_pb2 as qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2


class DataSourceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDataSourceSourceCodeUploadURL = channel.unary_unary(
                '/qwak.feature.store.management.v1.internal.sources.DataSourceService/GetDataSourceSourceCodeUploadURL',
                request_serializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadResponse.FromString,
                )
        self.GetDataSourceSourceCodeDownloadURL = channel.unary_unary(
                '/qwak.feature.store.management.v1.internal.sources.DataSourceService/GetDataSourceSourceCodeDownloadURL',
                request_serializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLResponse.FromString,
                )


class DataSourceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDataSourceSourceCodeUploadURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataSourceSourceCodeDownloadURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSourceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDataSourceSourceCodeUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataSourceSourceCodeUploadURL,
                    request_deserializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadResponse.SerializeToString,
            ),
            'GetDataSourceSourceCodeDownloadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataSourceSourceCodeDownloadURL,
                    request_deserializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.management.v1.internal.sources.DataSourceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataSourceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDataSourceSourceCodeUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.management.v1.internal.sources.DataSourceService/GetDataSourceSourceCodeUploadURL',
            qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadRequest.SerializeToString,
            qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataSourceSourceCodeDownloadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.management.v1.internal.sources.DataSourceService/GetDataSourceSourceCodeDownloadURL',
            qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLRequest.SerializeToString,
            qwak_dot_feature__store_dot_v1_dot_internal_dot_data__source_dot_data__source__service__pb2.GetDataSourceSourceCodeDownloadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.user_application.common.v0.resources_pb2
import qwak.user_application.v0.user_application_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Type:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Type.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CPU: _Type.ValueType  # 0
    GPU: _Type.ValueType  # 1

class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...

CPU: Type.ValueType  # 0
GPU: Type.ValueType  # 1
global___Type = Type

class _WorkspaceStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WorkspaceStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WorkspaceStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WORKSPACE_STATUS_UNKNOWN: _WorkspaceStatus.ValueType  # 0
    WORKSPACE_STATUS_INITIALIZING: _WorkspaceStatus.ValueType  # 1
    WORKSPACE_STATUS_STARTED: _WorkspaceStatus.ValueType  # 2
    WORKSPACE_STATUS_STOPPED: _WorkspaceStatus.ValueType  # 3
    WORKSPACE_STATUS_ERROR: _WorkspaceStatus.ValueType  # 4

class WorkspaceStatus(_WorkspaceStatus, metaclass=_WorkspaceStatusEnumTypeWrapper): ...

WORKSPACE_STATUS_UNKNOWN: WorkspaceStatus.ValueType  # 0
WORKSPACE_STATUS_INITIALIZING: WorkspaceStatus.ValueType  # 1
WORKSPACE_STATUS_STARTED: WorkspaceStatus.ValueType  # 2
WORKSPACE_STATUS_STOPPED: WorkspaceStatus.ValueType  # 3
WORKSPACE_STATUS_ERROR: WorkspaceStatus.ValueType  # 4
global___WorkspaceStatus = WorkspaceStatus

class _DeploymentState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeploymentStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeploymentState.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEPLOYMENT_STATE_UNKNOWN: _DeploymentState.ValueType  # 0
    DEPLOYMENT_STATE_INITIATING_WORKSPACE: _DeploymentState.ValueType  # 1
    DEPLOYMENT_STATE_DEPLOYING_REQUEST_WORKSPACE: _DeploymentState.ValueType  # 2
    DEPLOYMENT_STATE_FAILED_EVENT_COMMAND_WORKSPACE: _DeploymentState.ValueType  # 3
    DEPLOYMENT_STATE_DELETION_IN_PROGRESS: _DeploymentState.ValueType  # 4
    DEPLOYMENT_STATE_RESUME_EVENT_COMMAND_WORKSPACE: _DeploymentState.ValueType  # 5
    DEPLOYMENT_STATE_STOP_EVENT_COMMAND_WORKSPACE: _DeploymentState.ValueType  # 6
    DEPLOYMENT_STATE_STOPPING_DEPLOYMENT: _DeploymentState.ValueType  # 7
    DEPLOYMENT_STATE_STOPPED_DEPLOYMENT: _DeploymentState.ValueType  # 8
    DEPLOYMENT_STATE_INITIALIZED: _DeploymentState.ValueType  # 9
    DEPLOYMENT_STATE_READY: _DeploymentState.ValueType  # 10
    DEPLOYMENT_STATE_CONTAINERS_READY: _DeploymentState.ValueType  # 11
    DEPLOYMENT_STATE_POD_SCHEDULED: _DeploymentState.ValueType  # 12
    DEPLOYMENT_STATE_UNSCHEDULABLE: _DeploymentState.ValueType  # 13
    DEPLOYMENT_STATE_CONTAINERS_NOT_READY: _DeploymentState.ValueType  # 14
    DEPLOYMENT_STATE_AVAILABLE: _DeploymentState.ValueType  # 15
    DEPLOYMENT_STATE_PROGRESSING: _DeploymentState.ValueType  # 16
    DEPLOYMENT_STATE_REPLICA_FAILURE: _DeploymentState.ValueType  # 17
    DEPLOYMENT_STATE_MINIMUM_REPLICAS_AVAILABLE: _DeploymentState.ValueType  # 18
    DEPLOYMENT_STATE_MINIMUM_REPLICAS_UNAVAILABLE: _DeploymentState.ValueType  # 19
    DEPLOYMENT_STATE_PROGRESS_DEAD_LINE_EXCEEDED: _DeploymentState.ValueType  # 20
    DEPLOYMENT_STATE_NEW_REPLICA_SET_AVAILABLE: _DeploymentState.ValueType  # 21
    DEPLOYMENT_STATE_IDLE_TIME_STOPPED_DEPLOYMENT: _DeploymentState.ValueType  # 22

class DeploymentState(_DeploymentState, metaclass=_DeploymentStateEnumTypeWrapper): ...

DEPLOYMENT_STATE_UNKNOWN: DeploymentState.ValueType  # 0
DEPLOYMENT_STATE_INITIATING_WORKSPACE: DeploymentState.ValueType  # 1
DEPLOYMENT_STATE_DEPLOYING_REQUEST_WORKSPACE: DeploymentState.ValueType  # 2
DEPLOYMENT_STATE_FAILED_EVENT_COMMAND_WORKSPACE: DeploymentState.ValueType  # 3
DEPLOYMENT_STATE_DELETION_IN_PROGRESS: DeploymentState.ValueType  # 4
DEPLOYMENT_STATE_RESUME_EVENT_COMMAND_WORKSPACE: DeploymentState.ValueType  # 5
DEPLOYMENT_STATE_STOP_EVENT_COMMAND_WORKSPACE: DeploymentState.ValueType  # 6
DEPLOYMENT_STATE_STOPPING_DEPLOYMENT: DeploymentState.ValueType  # 7
DEPLOYMENT_STATE_STOPPED_DEPLOYMENT: DeploymentState.ValueType  # 8
DEPLOYMENT_STATE_INITIALIZED: DeploymentState.ValueType  # 9
DEPLOYMENT_STATE_READY: DeploymentState.ValueType  # 10
DEPLOYMENT_STATE_CONTAINERS_READY: DeploymentState.ValueType  # 11
DEPLOYMENT_STATE_POD_SCHEDULED: DeploymentState.ValueType  # 12
DEPLOYMENT_STATE_UNSCHEDULABLE: DeploymentState.ValueType  # 13
DEPLOYMENT_STATE_CONTAINERS_NOT_READY: DeploymentState.ValueType  # 14
DEPLOYMENT_STATE_AVAILABLE: DeploymentState.ValueType  # 15
DEPLOYMENT_STATE_PROGRESSING: DeploymentState.ValueType  # 16
DEPLOYMENT_STATE_REPLICA_FAILURE: DeploymentState.ValueType  # 17
DEPLOYMENT_STATE_MINIMUM_REPLICAS_AVAILABLE: DeploymentState.ValueType  # 18
DEPLOYMENT_STATE_MINIMUM_REPLICAS_UNAVAILABLE: DeploymentState.ValueType  # 19
DEPLOYMENT_STATE_PROGRESS_DEAD_LINE_EXCEEDED: DeploymentState.ValueType  # 20
DEPLOYMENT_STATE_NEW_REPLICA_SET_AVAILABLE: DeploymentState.ValueType  # 21
DEPLOYMENT_STATE_IDLE_TIME_STOPPED_DEPLOYMENT: DeploymentState.ValueType  # 22
global___DeploymentState = DeploymentState

class Workspace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    CREATOR_USER_ID_FIELD_NUMBER: builtins.int
    LAST_UPDATE_USER_ID_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIME_FIELD_NUMBER: builtins.int
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    WORKSPACE_DEPLOYMENT_STATE_FIELD_NUMBER: builtins.int
    WORKSPACE_STATUS_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    IMAGE_NAME_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    BUILD_IDS_FIELD_NUMBER: builtins.int
    workspace_name: builtins.str
    """Workspace name"""
    @property
    def client_pod_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources:
        """Deployment workspace pod compute resources"""
    image_id: builtins.str
    """Image id"""
    creator_user_id: builtins.str
    """Creator user of the workspace"""
    last_update_user_id: builtins.str
    """Last update user id of the workspace"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_update_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    workspace_id: builtins.str
    """Workspace id"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    workspace_deployment_state: global___DeploymentState.ValueType
    """Workspace deployment state"""
    workspace_status: global___WorkspaceStatus.ValueType
    """Workspace Status"""
    error_message: builtins.str
    """Error message"""
    image_name: builtins.str
    environment_id: builtins.str
    @property
    def build_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        workspace_name: builtins.str = ...,
        client_pod_compute_resources: qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources | None = ...,
        image_id: builtins.str = ...,
        creator_user_id: builtins.str = ...,
        last_update_user_id: builtins.str = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        workspace_id: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        workspace_deployment_state: global___DeploymentState.ValueType = ...,
        workspace_status: global___WorkspaceStatus.ValueType = ...,
        error_message: builtins.str = ...,
        image_name: builtins.str = ...,
        environment_id: builtins.str = ...,
        build_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_pod_compute_resources", b"client_pod_compute_resources", "create_time", b"create_time", "last_update_time", b"last_update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_ids", b"build_ids", "client_pod_compute_resources", b"client_pod_compute_resources", "create_time", b"create_time", "creator_user_id", b"creator_user_id", "environment_id", b"environment_id", "error_message", b"error_message", "image_id", b"image_id", "image_name", b"image_name", "last_update_time", b"last_update_time", "last_update_user_id", b"last_update_user_id", "tags", b"tags", "workspace_deployment_state", b"workspace_deployment_state", "workspace_id", b"workspace_id", "workspace_name", b"workspace_name", "workspace_status", b"workspace_status"]) -> None: ...

global___Workspace = Workspace

class WorkspaceSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    workspace_name: builtins.str
    """Workspace name"""
    @property
    def client_pod_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources:
        """Deployment workspace pod compute resources"""
    image_id: builtins.str
    """Image id"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Tags"""
    environment_id: builtins.str
    """Environment id"""
    build_id: builtins.str
    """Build id it was created from"""
    def __init__(
        self,
        *,
        workspace_name: builtins.str = ...,
        client_pod_compute_resources: qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources | None = ...,
        image_id: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        environment_id: builtins.str = ...,
        build_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_pod_compute_resources", b"client_pod_compute_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "client_pod_compute_resources", b"client_pod_compute_resources", "environment_id", b"environment_id", "image_id", b"image_id", "tags", b"tags", "workspace_name", b"workspace_name"]) -> None: ...

global___WorkspaceSpec = WorkspaceSpec

class WorkspaceDeploymentSnapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_NAME_FIELD_NUMBER: builtins.int
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    PODS_FIELD_NUMBER: builtins.int
    STATEFUL_SET_FIELD_NUMBER: builtins.int
    workspace_name: builtins.str
    """Workspace name"""
    workspace_id: builtins.str
    """Workspace id"""
    @property
    def deployment(self) -> qwak.user_application.v0.user_application_pb2.Spec:
        """Deployment spec"""
    @property
    def replicas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.user_application.v0.user_application_pb2.Spec]:
        """Replica spec"""
    @property
    def pods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.user_application.v0.user_application_pb2.Spec]:
        """Pod spec"""
    @property
    def stateful_set(self) -> qwak.user_application.v0.user_application_pb2.Spec:
        """StatefulSet spec"""
    def __init__(
        self,
        *,
        workspace_name: builtins.str = ...,
        workspace_id: builtins.str = ...,
        deployment: qwak.user_application.v0.user_application_pb2.Spec | None = ...,
        replicas: collections.abc.Iterable[qwak.user_application.v0.user_application_pb2.Spec] | None = ...,
        pods: collections.abc.Iterable[qwak.user_application.v0.user_application_pb2.Spec] | None = ...,
        stateful_set: qwak.user_application.v0.user_application_pb2.Spec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment", b"deployment", "stateful_set", b"stateful_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment", b"deployment", "pods", b"pods", "replicas", b"replicas", "stateful_set", b"stateful_set", "workspace_id", b"workspace_id", "workspace_name", b"workspace_name"]) -> None: ...

global___WorkspaceDeploymentSnapshot = WorkspaceDeploymentSnapshot

class UpdateWorkspaceStatusFromEdgeDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    WORKSPACE_DEPLOYMENT_SNAPSHOT_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    environment_id: builtins.str
    @property
    def workspace_deployment_snapshot(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspaceDeploymentSnapshot]: ...
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        workspace_deployment_snapshot: collections.abc.Iterable[global___WorkspaceDeploymentSnapshot] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "environment_id", b"environment_id", "workspace_deployment_snapshot", b"workspace_deployment_snapshot"]) -> None: ...

global___UpdateWorkspaceStatusFromEdgeDetails = UpdateWorkspaceStatusFromEdgeDetails

class WorkspaceImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    type: global___Type.ValueType
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        type: global___Type.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "type", b"type"]) -> None: ...

global___WorkspaceImage = WorkspaceImage

class DefaultWorkspaceDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    GPU_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    CPU_IMAGE_ID_FIELD_NUMBER: builtins.int
    GPU_IMAGE_ID_FIELD_NUMBER: builtins.int
    @property
    def cpu_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources: ...
    @property
    def gpu_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources: ...
    cpu_image_id: builtins.str
    gpu_image_id: builtins.str
    def __init__(
        self,
        *,
        cpu_compute_resources: qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources | None = ...,
        gpu_compute_resources: qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources | None = ...,
        cpu_image_id: builtins.str = ...,
        gpu_image_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cpu_compute_resources", b"cpu_compute_resources", "gpu_compute_resources", b"gpu_compute_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu_compute_resources", b"cpu_compute_resources", "cpu_image_id", b"cpu_image_id", "gpu_compute_resources", b"gpu_compute_resources", "gpu_image_id", b"gpu_image_id"]) -> None: ...

global___DefaultWorkspaceDetails = DefaultWorkspaceDetails



from _qwak_proto.qwak.self_service.user.v1.user_service_pb2 import (
    GenerateApiKeyRequest,
    GenerateApiKeyResponse,
    RevokeApiKeyRequest,
    RevokeApiKeyResponse,
)
from _qwak_proto.qwak.self_service.user.v1.user_service_pb2_grpc import UserServiceStub
from dependency_injector.wiring import Provide
from grpc import RpcError, StatusCode
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer

APIKEY_ALREADY_EXISTS = "Api-key already exists"


class SelfServiceUserClient:
    """
    Used for interacting with Qwak's Self service -  user service
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._user_service = UserServiceStub(grpc_channel)

    def generate_apikey(
        self,
        user_id: str,
        environment_id: str,
        force: bool = False,
    ) -> GenerateApiKeyResponse:
        """
        Generate api key
        user_id: the wanted user id.
        environment_id: the wanted environment id
        force: if override existing one.
        Return Api Key for the wanted user and environment.
        """
        request = GenerateApiKeyRequest(
            user_id=user_id, environment_id=environment_id, force=force
        )
        try:
            return self._user_service.GenerateApiKey(request)
        except RpcError as e:
            if e.code() == StatusCode.PERMISSION_DENIED:
                raise QwakException(
                    f"You are not authorized to perform administration operations. error is  {e.details()}"
                )
            elif e.code() == StatusCode.ALREADY_EXISTS:
                raise QwakException(APIKEY_ALREADY_EXISTS)
            raise QwakException(f"Failed to generate apikey, error is {e.details()}")

    def revoke_apikey(self, user_id: str, environment_id: str) -> RevokeApiKeyResponse:
        """
        Revoke api eky
        user_id: the wanted user id to revoke from
        environment_id: the wanted environment id
        Return if the api key has been revoked

        """
        try:
            request = RevokeApiKeyRequest(
                user_id=user_id, environment_id=environment_id
            )
            return self._user_service.RevokeApiKey(request)

        except RpcError as e:
            if e.code() == StatusCode.PERMISSION_DENIED:
                raise QwakException(
                    f"You are not authorized to perform administration operations. error is  {e.details()}"
                )
            raise QwakException(f"Failed to generate apikey, error is {e.details()}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/account/v0/managing_account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3qwak/self_service/account/v0/managing_account.proto\x12\x1cqwak.self_service.account.v0\x1a\x1fgoogle/protobuf/timestamp.proto\"\x12\n\x10\x43loudProviderAWS\"\x12\n\x10\x43loudProviderGCP\"\xb3\x01\n\x11\x43loudProviderSpec\x12=\n\x03\x61ws\x18\x01 \x01(\x0b\x32..qwak.self_service.account.v0.CloudProviderAWSH\x00\x12=\n\x03gcp\x18\x02 \x01(\x0b\x32..qwak.self_service.account.v0.CloudProviderGCPH\x00\x12\x0e\n\x06region\x18\x03 \x01(\tB\x10\n\x0e\x63loud_provider\"\xe9\x02\n\x14\x43reateAccountOptions\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12G\n\x0e\x63loud_provider\x18\x02 \x01(\x0e\x32+.qwak.self_service.account.v0.CloudProviderB\x02\x18\x01\x12P\n\x13\x63loud_provider_spec\x18\x03 \x01(\x0b\x32/.qwak.self_service.account.v0.CloudProviderSpecB\x02\x18\x01\x12S\n\x11jfrog_tenant_spec\x18\x04 \x01(\x0b\x32\x38.qwak.self_service.account.v0.SelfServiceJFrogTenantSpec\x12K\n\x12\x63luster_identifier\x18\x05 \x01(\x0b\x32/.qwak.self_service.account.v0.ClusterIdentifier\"d\n\x11\x43lusterIdentifier\x12G\n\ncluster_id\x18\x01 \x01(\x0b\x32\x31.qwak.self_service.account.v0.ClusterIdIdentifierH\x00\x42\x06\n\x04type\")\n\x13\x43lusterIdIdentifier\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xff\x01\n\x1f\x43reateAccountRequestDescription\x12L\n\x08metadata\x18\x01 \x01(\x0b\x32:.qwak.self_service.account.v0.CreateAccountRequestMetadata\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32\x36.qwak.self_service.account.v0.CreateAccountRequestSpec\x12H\n\x06status\x18\x03 \x01(\x0b\x32\x38.qwak.self_service.account.v0.CreateAccountRequestStatus\"x\n\x1c\x43reateAccountRequestMetadata\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0crequested_by\x18\x03 \x01(\t\"0\n\x18\x43reateAccountRequestSpec\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\"\x9d\x01\n\x1a\x43reateAccountRequestStatus\x12J\n\x04\x63ode\x18\x01 \x01(\x0e\x32<.qwak.self_service.account.v0.CreateAccountRequestStatusCode\x12\x33\n\x0flast_changed_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"l\n\x14\x43loudProviderRegions\x12\x43\n\x0e\x63loud_provider\x18\x01 \x01(\x0e\x32+.qwak.self_service.account.v0.CloudProvider\x12\x0f\n\x07regions\x18\x02 \x03(\t\"2\n\x1bSelfServiceJFrogProjectSpec\x12\x13\n\x0bproject_key\x18\x01 \x01(\t\"u\n\x1aSelfServiceJFrogTenantSpec\x12W\n\x14\x64\x65\x66\x61ult_project_spec\x18\x01 \x01(\x0b\x32\x39.qwak.self_service.account.v0.SelfServiceJFrogProjectSpec*=\n\rCloudProvider\x12\x1a\n\x16\x43LOUD_PROVIDER_INVALID\x10\x00\x12\x07\n\x03\x41WS\x10\x01\x12\x07\n\x03GCP\x10\x02*\xa9\x01\n\x1e\x43reateAccountRequestStatusCode\x12.\n*CREATE_ACCOUNT_REQUEST_STATUS_CODE_INVALID\x10\x00\x12\x13\n\x0fREQUEST_PENDING\x10\x01\x12\x16\n\x12REQUEST_REGISTERED\x10\x02\x12\x16\n\x12REQUEST_PROCESSING\x10\x03\x12\x12\n\x0eREQUEST_FAILED\x10\x04\x42\xb9\x01\n#com.qwak.ai.self_service.account.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.self_service.account.v0.managing_account_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.self_service.account.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0'
  _CREATEACCOUNTOPTIONS.fields_by_name['cloud_provider']._options = None
  _CREATEACCOUNTOPTIONS.fields_by_name['cloud_provider']._serialized_options = b'\030\001'
  _CREATEACCOUNTOPTIONS.fields_by_name['cloud_provider_spec']._options = None
  _CREATEACCOUNTOPTIONS.fields_by_name['cloud_provider_spec']._serialized_options = b'\030\001'
  _globals['_CLOUDPROVIDER']._serialized_start=1720
  _globals['_CLOUDPROVIDER']._serialized_end=1781
  _globals['_CREATEACCOUNTREQUESTSTATUSCODE']._serialized_start=1784
  _globals['_CREATEACCOUNTREQUESTSTATUSCODE']._serialized_end=1953
  _globals['_CLOUDPROVIDERAWS']._serialized_start=118
  _globals['_CLOUDPROVIDERAWS']._serialized_end=136
  _globals['_CLOUDPROVIDERGCP']._serialized_start=138
  _globals['_CLOUDPROVIDERGCP']._serialized_end=156
  _globals['_CLOUDPROVIDERSPEC']._serialized_start=159
  _globals['_CLOUDPROVIDERSPEC']._serialized_end=338
  _globals['_CREATEACCOUNTOPTIONS']._serialized_start=341
  _globals['_CREATEACCOUNTOPTIONS']._serialized_end=702
  _globals['_CLUSTERIDENTIFIER']._serialized_start=704
  _globals['_CLUSTERIDENTIFIER']._serialized_end=804
  _globals['_CLUSTERIDIDENTIFIER']._serialized_start=806
  _globals['_CLUSTERIDIDENTIFIER']._serialized_end=847
  _globals['_CREATEACCOUNTREQUESTDESCRIPTION']._serialized_start=850
  _globals['_CREATEACCOUNTREQUESTDESCRIPTION']._serialized_end=1105
  _globals['_CREATEACCOUNTREQUESTMETADATA']._serialized_start=1107
  _globals['_CREATEACCOUNTREQUESTMETADATA']._serialized_end=1227
  _globals['_CREATEACCOUNTREQUESTSPEC']._serialized_start=1229
  _globals['_CREATEACCOUNTREQUESTSPEC']._serialized_end=1277
  _globals['_CREATEACCOUNTREQUESTSTATUS']._serialized_start=1280
  _globals['_CREATEACCOUNTREQUESTSTATUS']._serialized_end=1437
  _globals['_CLOUDPROVIDERREGIONS']._serialized_start=1439
  _globals['_CLOUDPROVIDERREGIONS']._serialized_end=1547
  _globals['_SELFSERVICEJFROGPROJECTSPEC']._serialized_start=1549
  _globals['_SELFSERVICEJFROGPROJECTSPEC']._serialized_end=1599
  _globals['_SELFSERVICEJFROGTENANTSPEC']._serialized_start=1601
  _globals['_SELFSERVICEJFROGTENANTSPEC']._serialized_end=1718
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.audience.v1.audience_pb2
import qwak.build.v1.build_pb2
import qwak.builds.builds_pb2
import qwak.deployment.deployment_pb2
import qwak.models.models_query_pb2
import qwak.projects.jfrog_project_spec_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DeploymentModelStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeploymentModelStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeploymentModelStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEPLOYMENT_STATUS_INVALID: _DeploymentModelStatus.ValueType  # 0
    ONLINE: _DeploymentModelStatus.ValueType  # 1
    OFFLINE: _DeploymentModelStatus.ValueType  # 2

class DeploymentModelStatus(_DeploymentModelStatus, metaclass=_DeploymentModelStatusEnumTypeWrapper): ...

DEPLOYMENT_STATUS_INVALID: DeploymentModelStatus.ValueType  # 0
ONLINE: DeploymentModelStatus.ValueType  # 1
OFFLINE: DeploymentModelStatus.ValueType  # 2
global___DeploymentModelStatus = DeploymentModelStatus

class _ModelStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModelStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModelStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID: _ModelStatus.ValueType  # 0
    ACTIVE: _ModelStatus.ValueType  # 3
    SUSPENDED: _ModelStatus.ValueType  # 2
    DISABLED: _ModelStatus.ValueType  # 1

class ModelStatus(_ModelStatus, metaclass=_ModelStatusEnumTypeWrapper):
    """Model Status
    Active - Live model
    Suspended - Suspended model
    Disabled - Deleted model
    """

INVALID: ModelStatus.ValueType  # 0
ACTIVE: ModelStatus.ValueType  # 3
SUSPENDED: ModelStatus.ValueType  # 2
DISABLED: ModelStatus.ValueType  # 1
global___ModelStatus = ModelStatus

class _MemoryUnit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MemoryUnitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MemoryUnit.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MEMORY_UNIT_UNKNOWN: _MemoryUnit.ValueType  # 0
    MIB: _MemoryUnit.ValueType  # 1
    GIB: _MemoryUnit.ValueType  # 2

class MemoryUnit(_MemoryUnit, metaclass=_MemoryUnitEnumTypeWrapper): ...

MEMORY_UNIT_UNKNOWN: MemoryUnit.ValueType  # 0
MIB: MemoryUnit.ValueType  # 1
GIB: MemoryUnit.ValueType  # 2
global___MemoryUnit = MemoryUnit

class CreateModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_SPEC_FIELD_NUMBER: builtins.int
    JFROG_PROJECT_SPEC_FIELD_NUMBER: builtins.int
    @property
    def model_spec(self) -> global___ModelSpec:
        """Model spec to add"""
    @property
    def jfrog_project_spec(self) -> qwak.projects.jfrog_project_spec_pb2.ModelRepositoryJFrogSpec:
        """JFrog project spec to add in case we want to associate the created model to another project than default"""
    def __init__(
        self,
        *,
        model_spec: global___ModelSpec | None = ...,
        jfrog_project_spec: qwak.projects.jfrog_project_spec_pb2.ModelRepositoryJFrogSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jfrog_project_spec", b"jfrog_project_spec", "model_spec", b"model_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_project_spec", b"jfrog_project_spec", "model_spec", b"model_spec"]) -> None: ...

global___CreateModelRequest = CreateModelRequest

class CreateModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_id", b"model_id"]) -> None: ...

global___CreateModelResponse = CreateModelResponse

class ListModelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """The project id"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_id", b"project_id"]) -> None: ...

global___ListModelsRequest = ListModelsRequest

class ListModelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODELS_FIELD_NUMBER: builtins.int
    @property
    def models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Model]:
        """List of models"""
    def __init__(
        self,
        *,
        models: collections.abc.Iterable[global___Model] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["models", b"models"]) -> None: ...

global___ListModelsResponse = ListModelsResponse

class ListModelsPaginatedRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    SORT_MODELS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    cursor: builtins.str
    @property
    def sort_models(self) -> qwak.models.models_query_pb2.SortModels: ...
    @property
    def filter(self) -> qwak.models.models_query_pb2.Filter: ...
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        cursor: builtins.str = ...,
        sort_models: qwak.models.models_query_pb2.SortModels | None = ...,
        filter: qwak.models.models_query_pb2.Filter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "cursor_opt", b"cursor_opt", "filter", b"filter", "filter_opt", b"filter_opt", "page_size", b"page_size", "page_size_opt", b"page_size_opt", "sort_models", b"sort_models", "sort_models_opt", b"sort_models_opt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "cursor_opt", b"cursor_opt", "filter", b"filter", "filter_opt", b"filter_opt", "page_size", b"page_size", "page_size_opt", b"page_size_opt", "sort_models", b"sort_models", "sort_models_opt", b"sort_models_opt"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cursor_opt", b"cursor_opt"]) -> typing_extensions.Literal["cursor"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["filter_opt", b"filter_opt"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["page_size_opt", b"page_size_opt"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["sort_models_opt", b"sort_models_opt"]) -> typing_extensions.Literal["sort_models"] | None: ...

global___ListModelsPaginatedRequest = ListModelsPaginatedRequest

class ListModelsPaginatedResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODELS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Model]:
        """List of models matching the query criteria."""
    @property
    def metadata(self) -> qwak.models.models_query_pb2.PaginationMetadata:
        """Pagination information about the result set."""
    def __init__(
        self,
        *,
        models: collections.abc.Iterable[global___Model] | None = ...,
        metadata: qwak.models.models_query_pb2.PaginationMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "models", b"models"]) -> None: ...

global___ListModelsPaginatedResponse = ListModelsPaginatedResponse

class GetModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id"""
    model_uuid: builtins.str
    """The model uuid"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        model_uuid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "model_id", b"model_id", "model_uuid", b"model_uuid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "model_id", b"model_id", "model_uuid", b"model_uuid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["identifier", b"identifier"]) -> typing_extensions.Literal["model_id", "model_uuid"] | None: ...

global___GetModelRequest = GetModelRequest

class GetModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_FIELD_NUMBER: builtins.int
    @property
    def model(self) -> global___Model:
        """The model"""
    def __init__(
        self,
        *,
        model: global___Model | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model", b"model"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model", b"model"]) -> None: ...

global___GetModelResponse = GetModelResponse

class DeleteModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id"""
    project_id: builtins.str
    """The project id"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_id", b"model_id", "project_id", b"project_id"]) -> None: ...

global___DeleteModelRequest = DeleteModelRequest

class DeleteModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteModelResponse = DeleteModelResponse

class UpdateModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    MODEL_SPEC_CONFIG_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id to update"""
    @property
    def model_spec_config(self) -> global___ModelSpecConfiguration:
        """The model specification to update"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        model_spec_config: global___ModelSpecConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_spec_config", b"model_spec_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_id", b"model_id", "model_spec_config", b"model_spec_config"]) -> None: ...

global___UpdateModelRequest = UpdateModelRequest

class UpdateModelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_SPEC_FIELD_NUMBER: builtins.int
    @property
    def model_spec(self) -> global___ModelSpec:
        """The updated model specification"""
    def __init__(
        self,
        *,
        model_spec: global___ModelSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_spec", b"model_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_spec", b"model_spec"]) -> None: ...

global___UpdateModelResponse = UpdateModelResponse

class CreateBranchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_NAME_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id"""
    branch_name: builtins.str
    """The branch name"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_name", b"branch_name", "model_id", b"model_id"]) -> None: ...

global___CreateBranchRequest = CreateBranchRequest

class CreateBranchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_ID_FIELD_NUMBER: builtins.int
    branch_id: builtins.str
    """The created branch"""
    def __init__(
        self,
        *,
        branch_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id"]) -> None: ...

global___CreateBranchResponse = CreateBranchResponse

class DeleteBranchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_ID_FIELD_NUMBER: builtins.int
    branch_id: builtins.str
    """The branch id"""
    def __init__(
        self,
        *,
        branch_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id"]) -> None: ...

global___DeleteBranchRequest = DeleteBranchRequest

class DeleteBranchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteBranchResponse = DeleteBranchResponse

class IsModelExistsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model id (e.g. name)"""
    model_uuid: builtins.str
    """Model Uuid"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        model_uuid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "model_id", b"model_id", "model_uuid", b"model_uuid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "model_id", b"model_id", "model_uuid", b"model_uuid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["identifier", b"identifier"]) -> typing_extensions.Literal["model_id", "model_uuid"] | None: ...

global___IsModelExistsRequest = IsModelExistsRequest

class IsModelExistsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXISTS_FIELD_NUMBER: builtins.int
    exists: builtins.bool
    """Does the model exist"""
    def __init__(
        self,
        *,
        exists: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exists", b"exists"]) -> None: ...

global___IsModelExistsResponse = IsModelExistsResponse

class ModelSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAMED_ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    MODEL_DESCRIPTION_FIELD_NUMBER: builtins.int
    MODEL_BUILD_TYPE_FIELD_NUMBER: builtins.int
    model_named_id: builtins.str
    """The model id"""
    display_name: builtins.str
    """The display name"""
    project_id: builtins.str
    project_name: builtins.str
    model_description: builtins.str
    """The model description"""
    @property
    def model_build_type(self) -> global___ModelBuildType:
        """The Model build type"""
    def __init__(
        self,
        *,
        model_named_id: builtins.str = ...,
        display_name: builtins.str = ...,
        project_id: builtins.str = ...,
        project_name: builtins.str = ...,
        model_description: builtins.str = ...,
        model_build_type: global___ModelBuildType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_build_type", b"model_build_type", "project_id", b"project_id", "project_identifier", b"project_identifier", "project_name", b"project_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "model_build_type", b"model_build_type", "model_description", b"model_description", "model_named_id", b"model_named_id", "project_id", b"project_id", "project_identifier", b"project_identifier", "project_name", b"project_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["project_identifier", b"project_identifier"]) -> typing_extensions.Literal["project_id", "project_name"] | None: ...

global___ModelSpec = ModelSpec

class ModelBrief(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    MODEL_DESCRIPTION_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_MODEL_STATUS_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id"""
    display_name: builtins.str
    """The display name"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Create at"""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last modified"""
    last_modified_by: builtins.str
    """Last modified by"""
    created_by: builtins.str
    """Created by"""
    model_description: builtins.str
    """The model description"""
    project_id: builtins.str
    """The project id"""
    deployment_model_status: global___DeploymentModelStatus.ValueType
    """The Model status"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        display_name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_by: builtins.str = ...,
        created_by: builtins.str = ...,
        model_description: builtins.str = ...,
        project_id: builtins.str = ...,
        deployment_model_status: global___DeploymentModelStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "deployment_model_status", b"deployment_model_status", "display_name", b"display_name", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by", "model_description", b"model_description", "model_id", b"model_id", "project_id", b"project_id"]) -> None: ...

global___ModelBrief = ModelBrief

class ModelSpecConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_DESCRIPTION_FIELD_NUMBER: builtins.int
    model_description: builtins.str
    """The model description"""
    def __init__(
        self,
        *,
        model_description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_description", b"model_description"]) -> None: ...

global___ModelSpecConfiguration = ModelSpecConfiguration

class Model(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    MODEL_STATUS_FIELD_NUMBER: builtins.int
    MODEL_DESCRIPTION_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    BRANCHES_FIELD_NUMBER: builtins.int
    DEPLOYMENT_MODEL_STATUS_FIELD_NUMBER: builtins.int
    UUID_FIELD_NUMBER: builtins.int
    MODEL_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    MODEL_BUILD_TYPE_FIELD_NUMBER: builtins.int
    JFROG_PROJECT_KEY_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id"""
    display_name: builtins.str
    """The display name"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Create at"""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last modified"""
    last_modified_by: builtins.str
    """Last modified by"""
    created_by: builtins.str
    """Created by"""
    model_status: global___ModelStatus.ValueType
    """Models Status"""
    model_description: builtins.str
    """The model description"""
    project_id: builtins.str
    """The project id"""
    @property
    def branches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Branch]:
        """List of branches"""
    deployment_model_status: global___DeploymentModelStatus.ValueType
    """The deployment status of the model"""
    uuid: builtins.str
    """unique id for model."""
    model_type: qwak.deployment.deployment_pb2.KubeDeploymentType.ValueType
    """The deployment type of the model"""
    project_name: builtins.str
    """Project name"""
    @property
    def model_build_type(self) -> global___ModelBuildType:
        """Model build type"""
    jfrog_project_key: builtins.str
    """Jfrog project key"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        display_name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_by: builtins.str = ...,
        created_by: builtins.str = ...,
        model_status: global___ModelStatus.ValueType = ...,
        model_description: builtins.str = ...,
        project_id: builtins.str = ...,
        branches: collections.abc.Iterable[global___Branch] | None = ...,
        deployment_model_status: global___DeploymentModelStatus.ValueType = ...,
        uuid: builtins.str = ...,
        model_type: qwak.deployment.deployment_pb2.KubeDeploymentType.ValueType = ...,
        project_name: builtins.str = ...,
        model_build_type: global___ModelBuildType | None = ...,
        jfrog_project_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "last_modified_at", b"last_modified_at", "model_build_type", b"model_build_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branches", b"branches", "created_at", b"created_at", "created_by", b"created_by", "deployment_model_status", b"deployment_model_status", "display_name", b"display_name", "jfrog_project_key", b"jfrog_project_key", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by", "model_build_type", b"model_build_type", "model_description", b"model_description", "model_id", b"model_id", "model_status", b"model_status", "model_type", b"model_type", "project_id", b"project_id", "project_name", b"project_name", "uuid", b"uuid"]) -> None: ...

global___Model = Model

class ModelBuildType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    MODEL_REGISTRY_IMAGE_FIELD_NUMBER: builtins.int
    @property
    def source(self) -> global___Source: ...
    @property
    def model_registry_image(self) -> global___ModelRegistryImage: ...
    def __init__(
        self,
        *,
        source: global___Source | None = ...,
        model_registry_image: global___ModelRegistryImage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_registry_image", b"model_registry_image", "source", b"source", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_registry_image", b"model_registry_image", "source", b"source", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["source", "model_registry_image"] | None: ...

global___ModelBuildType = ModelBuildType

class Source(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Source = Source

class ModelRegistryImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_IMAGE_IDENTIFIER_FIELD_NUMBER: builtins.int
    last_image_identifier: builtins.str
    def __init__(
        self,
        *,
        last_image_identifier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_image_identifier", b"last_image_identifier"]) -> None: ...

global___ModelRegistryImage = ModelRegistryImage

class Branch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BranchStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BranchStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Branch._BranchStatus.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID: Branch._BranchStatus.ValueType  # 0
        ACTIVE: Branch._BranchStatus.ValueType  # 3
        SUSPENDED: Branch._BranchStatus.ValueType  # 2
        DISABLED: Branch._BranchStatus.ValueType  # 1

    class BranchStatus(_BranchStatus, metaclass=_BranchStatusEnumTypeWrapper):
        """Branch Status
        Active - Live branch
        Suspended - Suspended branch
        Disabled - Deleted branch
        """

    INVALID: Branch.BranchStatus.ValueType  # 0
    ACTIVE: Branch.BranchStatus.ValueType  # 3
    SUSPENDED: Branch.BranchStatus.ValueType  # 2
    DISABLED: Branch.BranchStatus.ValueType  # 1

    BRANCH_ID_FIELD_NUMBER: builtins.int
    BRANCH_NAME_FIELD_NUMBER: builtins.int
    BRANCH_STATUS_FIELD_NUMBER: builtins.int
    MODEL_ID_FIELD_NUMBER: builtins.int
    DEPLOYED_BUILD_ID_FIELD_NUMBER: builtins.int
    branch_id: builtins.str
    """The branch id"""
    branch_name: builtins.str
    """The branch name"""
    branch_status: global___Branch.BranchStatus.ValueType
    """Branch Status"""
    model_id: builtins.str
    """The model ID"""
    deployed_build_id: builtins.str
    """The deployed build"""
    def __init__(
        self,
        *,
        branch_id: builtins.str = ...,
        branch_name: builtins.str = ...,
        branch_status: global___Branch.BranchStatus.ValueType = ...,
        model_id: builtins.str = ...,
        deployed_build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "branch_name", b"branch_name", "branch_status", b"branch_status", "deployed_build_id", b"deployed_build_id", "model_id", b"model_id"]) -> None: ...

global___Branch = Branch

class GetDeploymentDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model ID"""
    branch_id: builtins.str
    """The branch ID"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "model_id", b"model_id"]) -> None: ...

global___GetDeploymentDetailsRequest = GetDeploymentDetailsRequest

class GetDeploymentDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def deployment_details(self) -> global___DeploymentDetails: ...
    def __init__(
        self,
        *,
        deployment_details: global___DeploymentDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_details", b"deployment_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_details", b"deployment_details"]) -> None: ...

global___GetDeploymentDetailsResponse = GetDeploymentDetailsResponse

class DeploymentDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_DEPLOYED_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    NUMBER_OF_PODS_FIELD_NUMBER: builtins.int
    CPU_FRACTION_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNITS_FIELD_NUMBER: builtins.int
    NUMBER_OF_WORKERS_FIELD_NUMBER: builtins.int
    HTTP_REQUEST_TIMEOUT_MS_FIELD_NUMBER: builtins.int
    @property
    def last_deployed(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Deployed date"""
    build_id: builtins.str
    """The build id that deployed"""
    number_of_pods: builtins.int
    """Number of pods to deploy"""
    cpu_fraction: builtins.float
    """Cpu"""
    memory_amount: builtins.int
    """Amount of memory"""
    memory_units: global___MemoryUnit.ValueType
    """Units type of memory"""
    number_of_workers: builtins.int
    """Number of workers"""
    http_request_timeout_ms: builtins.int
    """Timeout for request timeout"""
    def __init__(
        self,
        *,
        last_deployed: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        build_id: builtins.str = ...,
        number_of_pods: builtins.int = ...,
        cpu_fraction: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_units: global___MemoryUnit.ValueType = ...,
        number_of_workers: builtins.int = ...,
        http_request_timeout_ms: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_deployed", b"last_deployed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "cpu_fraction", b"cpu_fraction", "http_request_timeout_ms", b"http_request_timeout_ms", "last_deployed", b"last_deployed", "memory_amount", b"memory_amount", "memory_units", b"memory_units", "number_of_pods", b"number_of_pods", "number_of_workers", b"number_of_workers"]) -> None: ...

global___DeploymentDetails = DeploymentDetails

class ListModelsMetadataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """The project id"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_id", b"project_id"]) -> None: ...

global___ListModelsMetadataRequest = ListModelsMetadataRequest

class ListModelsMetadataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_METADATA_FIELD_NUMBER: builtins.int
    @property
    def model_metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelMetadata]: ...
    def __init__(
        self,
        *,
        model_metadata: collections.abc.Iterable[global___ModelMetadata] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_metadata", b"model_metadata"]) -> None: ...

global___ListModelsMetadataResponse = ListModelsMetadataResponse

class GetModelMetadataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_id", b"model_id"]) -> None: ...

global___GetModelMetadataRequest = GetModelMetadataRequest

class GetModelMetadataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_METADATA_FIELD_NUMBER: builtins.int
    @property
    def model_metadata(self) -> global___ModelMetadata: ...
    def __init__(
        self,
        *,
        model_metadata: global___ModelMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_metadata", b"model_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_metadata", b"model_metadata"]) -> None: ...

global___GetModelMetadataResponse = GetModelMetadataResponse

class EnvironmentRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    AUDIENCE_ROUTES_FIELD_NUMBER: builtins.int
    environment: builtins.str
    @property
    def audience_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.audience.v1.audience_pb2.AudienceRoutesEntry]: ...
    def __init__(
        self,
        *,
        environment: builtins.str = ...,
        audience_routes: collections.abc.Iterable[qwak.audience.v1.audience_pb2.AudienceRoutesEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_routes", b"audience_routes", "environment", b"environment"]) -> None: ...

global___EnvironmentRoutes = EnvironmentRoutes

class ModelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class AudienceRoutesByEnvironmentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.audience.v1.audience_pb2.AudienceRoutesEntry: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.audience.v1.audience_pb2.AudienceRoutesEntry | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class AudienceRoutesGroupedByEnvironmentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___EnvironmentRoutes: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___EnvironmentRoutes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    MODEL_FIELD_NUMBER: builtins.int
    DEPLOYMENT_DETAILS_FIELD_NUMBER: builtins.int
    AUDIENCE_ROUTES_BY_ENVIRONMENT_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    AUDIENCE_ROUTES_GROUPED_BY_ENVIRONMENT_FIELD_NUMBER: builtins.int
    BUILDS_FIELD_NUMBER: builtins.int
    @property
    def model(self) -> global___Model: ...
    @property
    def deployment_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.deployment_pb2.DeploymentDetails]: ...
    @property
    def audience_routes_by_environment(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.audience.v1.audience_pb2.AudienceRoutesEntry]: ...
    @property
    def build(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.builds.builds_pb2.Build]: ...
    @property
    def audience_routes_grouped_by_environment(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___EnvironmentRoutes]: ...
    @property
    def builds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.build.v1.build_pb2.Build]: ...
    def __init__(
        self,
        *,
        model: global___Model | None = ...,
        deployment_details: collections.abc.Iterable[qwak.deployment.deployment_pb2.DeploymentDetails] | None = ...,
        audience_routes_by_environment: collections.abc.Mapping[builtins.str, qwak.audience.v1.audience_pb2.AudienceRoutesEntry] | None = ...,
        build: collections.abc.Iterable[qwak.builds.builds_pb2.Build] | None = ...,
        audience_routes_grouped_by_environment: collections.abc.Mapping[builtins.str, global___EnvironmentRoutes] | None = ...,
        builds: collections.abc.Iterable[qwak.build.v1.build_pb2.Build] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model", b"model"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_routes_by_environment", b"audience_routes_by_environment", "audience_routes_grouped_by_environment", b"audience_routes_grouped_by_environment", "build", b"build", "builds", b"builds", "deployment_details", b"deployment_details", "model", b"model"]) -> None: ...

global___ModelMetadata = ModelMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import qwak.user_application.common.v0.resources_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BatchJobEventTypeMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BatchJobEventTypeMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BatchJobEventTypeMessage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_BATCH_JOB_EVENT: _BatchJobEventTypeMessage.ValueType  # 0
    BATCH_JOB_COMMITTED: _BatchJobEventTypeMessage.ValueType  # 1
    BATCH_JOB_PREPARED: _BatchJobEventTypeMessage.ValueType  # 7
    BATCH_JOB_TASKS_CREATED: _BatchJobEventTypeMessage.ValueType  # 2
    BATCH_JOB_CANCELLED: _BatchJobEventTypeMessage.ValueType  # 3
    BATCH_JOB_CLEANUP: _BatchJobEventTypeMessage.ValueType  # 4
    BATCH_JOB_CHECK_FINISHED: _BatchJobEventTypeMessage.ValueType  # 5
    BATCH_JOB_CHECK_TIMEOUT: _BatchJobEventTypeMessage.ValueType  # 6

class BatchJobEventTypeMessage(_BatchJobEventTypeMessage, metaclass=_BatchJobEventTypeMessageEnumTypeWrapper): ...

UNDEFINED_BATCH_JOB_EVENT: BatchJobEventTypeMessage.ValueType  # 0
BATCH_JOB_COMMITTED: BatchJobEventTypeMessage.ValueType  # 1
BATCH_JOB_PREPARED: BatchJobEventTypeMessage.ValueType  # 7
BATCH_JOB_TASKS_CREATED: BatchJobEventTypeMessage.ValueType  # 2
BATCH_JOB_CANCELLED: BatchJobEventTypeMessage.ValueType  # 3
BATCH_JOB_CLEANUP: BatchJobEventTypeMessage.ValueType  # 4
BATCH_JOB_CHECK_FINISHED: BatchJobEventTypeMessage.ValueType  # 5
BATCH_JOB_CHECK_TIMEOUT: BatchJobEventTypeMessage.ValueType  # 6
global___BatchJobEventTypeMessage = BatchJobEventTypeMessage

class _BatchTaskEventTypeMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BatchTaskEventTypeMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BatchTaskEventTypeMessage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_BATCH_TASK_EVENT: _BatchTaskEventTypeMessage.ValueType  # 0
    BATCH_TASK_RUNNING: _BatchTaskEventTypeMessage.ValueType  # 1
    BATCH_TASK_FINISHED: _BatchTaskEventTypeMessage.ValueType  # 2
    BATCH_TASK_FAILED: _BatchTaskEventTypeMessage.ValueType  # 3
    BATCH_TASK_CHECK_STATUS: _BatchTaskEventTypeMessage.ValueType  # 4
    BATCH_TASK_START: _BatchTaskEventTypeMessage.ValueType  # 5
    BATCH_TASK_CLEANUP: _BatchTaskEventTypeMessage.ValueType  # 6

class BatchTaskEventTypeMessage(_BatchTaskEventTypeMessage, metaclass=_BatchTaskEventTypeMessageEnumTypeWrapper): ...

UNDEFINED_BATCH_TASK_EVENT: BatchTaskEventTypeMessage.ValueType  # 0
BATCH_TASK_RUNNING: BatchTaskEventTypeMessage.ValueType  # 1
BATCH_TASK_FINISHED: BatchTaskEventTypeMessage.ValueType  # 2
BATCH_TASK_FAILED: BatchTaskEventTypeMessage.ValueType  # 3
BATCH_TASK_CHECK_STATUS: BatchTaskEventTypeMessage.ValueType  # 4
BATCH_TASK_START: BatchTaskEventTypeMessage.ValueType  # 5
BATCH_TASK_CLEANUP: BatchTaskEventTypeMessage.ValueType  # 6
global___BatchTaskEventTypeMessage = BatchTaskEventTypeMessage

class _WarmupEventTypeMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _WarmupEventTypeMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_WarmupEventTypeMessage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_WARMUP_JOB_EVENT: _WarmupEventTypeMessage.ValueType  # 0
    WARMUP_JOB_COMMITTED: _WarmupEventTypeMessage.ValueType  # 1
    WARMUP_CANCEL: _WarmupEventTypeMessage.ValueType  # 2

class WarmupEventTypeMessage(_WarmupEventTypeMessage, metaclass=_WarmupEventTypeMessageEnumTypeWrapper): ...

UNDEFINED_WARMUP_JOB_EVENT: WarmupEventTypeMessage.ValueType  # 0
WARMUP_JOB_COMMITTED: WarmupEventTypeMessage.ValueType  # 1
WARMUP_CANCEL: WarmupEventTypeMessage.ValueType  # 2
global___WarmupEventTypeMessage = WarmupEventTypeMessage

class _MemoryUnit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MemoryUnitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MemoryUnit.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _MemoryUnit.ValueType  # 0
    MIB: _MemoryUnit.ValueType  # 1
    GIB: _MemoryUnit.ValueType  # 2

class MemoryUnit(_MemoryUnit, metaclass=_MemoryUnitEnumTypeWrapper): ...

UNKNOWN: MemoryUnit.ValueType  # 0
MIB: MemoryUnit.ValueType  # 1
GIB: MemoryUnit.ValueType  # 2
global___MemoryUnit = MemoryUnit

class _TaskFailureReasonCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TaskFailureReasonCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TaskFailureReasonCode.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TASK_FAILURE_REASON_CODE_FAILURE_CODE_UNSPECIFIED: _TaskFailureReasonCode.ValueType  # 0
    TASK_FAILURE_REASON_CODE_NO_REPLICA_SETS_PODS_FOUND_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 1
    TASK_FAILURE_REASON_CODE_MODEL_CONTAINER_NOT_FOUND_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 2
    TASK_FAILURE_REASON_CODE_UNSCHEDULABLE_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 3
    TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_NOT_FOUND_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 4
    TASK_FAILURE_REASON_CODE_MEMORY_LIMIT_EXCEEDED_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 5
    TASK_FAILURE_REASON_CODE_CRASH_LOOP_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 6
    TASK_FAILURE_REASON_CODE_CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON: _TaskFailureReasonCode.ValueType  # 7
    TASK_FAILURE_REASON_CODE_UNKNOWN_REASON: _TaskFailureReasonCode.ValueType  # 8
    TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_GETS_THROTTLING_BY_CLOUD_PROVIDER_FAILURE_CODE: _TaskFailureReasonCode.ValueType  # 9

class TaskFailureReasonCode(_TaskFailureReasonCode, metaclass=_TaskFailureReasonCodeEnumTypeWrapper): ...

TASK_FAILURE_REASON_CODE_FAILURE_CODE_UNSPECIFIED: TaskFailureReasonCode.ValueType  # 0
TASK_FAILURE_REASON_CODE_NO_REPLICA_SETS_PODS_FOUND_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 1
TASK_FAILURE_REASON_CODE_MODEL_CONTAINER_NOT_FOUND_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 2
TASK_FAILURE_REASON_CODE_UNSCHEDULABLE_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 3
TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_NOT_FOUND_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 4
TASK_FAILURE_REASON_CODE_MEMORY_LIMIT_EXCEEDED_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 5
TASK_FAILURE_REASON_CODE_CRASH_LOOP_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 6
TASK_FAILURE_REASON_CODE_CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON: TaskFailureReasonCode.ValueType  # 7
TASK_FAILURE_REASON_CODE_UNKNOWN_REASON: TaskFailureReasonCode.ValueType  # 8
TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_GETS_THROTTLING_BY_CLOUD_PROVIDER_FAILURE_CODE: TaskFailureReasonCode.ValueType  # 9
global___TaskFailureReasonCode = TaskFailureReasonCode

class BatchJobEventMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_JOB_EVENT_TYPE_FIELD_NUMBER: builtins.int
    BATCH_JOB_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    FAILURES_FIELD_NUMBER: builtins.int
    batch_job_event_type: global___BatchJobEventTypeMessage.ValueType
    batch_job_id: builtins.str
    message: builtins.str
    delay: builtins.int
    failures: builtins.int
    def __init__(
        self,
        *,
        batch_job_event_type: global___BatchJobEventTypeMessage.ValueType = ...,
        batch_job_id: builtins.str = ...,
        message: builtins.str = ...,
        delay: builtins.int = ...,
        failures: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_job_event_type", b"batch_job_event_type", "batch_job_id", b"batch_job_id", "delay", b"delay", "failures", b"failures", "message", b"message"]) -> None: ...

global___BatchJobEventMessage = BatchJobEventMessage

class BatchTaskEventMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_TASK_EVENT_TYPE_FIELD_NUMBER: builtins.int
    BATCH_JOB_ID_FIELD_NUMBER: builtins.int
    BATCH_TASK_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    FAILURES_FIELD_NUMBER: builtins.int
    BATCH_TASK_FAILURE_REASON_FIELD_NUMBER: builtins.int
    batch_task_event_type: global___BatchTaskEventTypeMessage.ValueType
    batch_job_id: builtins.str
    batch_task_id: builtins.str
    message: builtins.str
    delay: builtins.int
    failures: builtins.int
    @property
    def batch_task_failure_reason(self) -> global___TaskFailureReason: ...
    def __init__(
        self,
        *,
        batch_task_event_type: global___BatchTaskEventTypeMessage.ValueType = ...,
        batch_job_id: builtins.str = ...,
        batch_task_id: builtins.str = ...,
        message: builtins.str = ...,
        delay: builtins.int = ...,
        failures: builtins.int = ...,
        batch_task_failure_reason: global___TaskFailureReason | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_task_failure_reason", b"batch_task_failure_reason"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_job_id", b"batch_job_id", "batch_task_event_type", b"batch_task_event_type", "batch_task_failure_reason", b"batch_task_failure_reason", "batch_task_id", b"batch_task_id", "delay", b"delay", "failures", b"failures", "message", b"message"]) -> None: ...

global___BatchTaskEventMessage = BatchTaskEventMessage

class WarmupEventMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WARMUP_JOB_EVENT_TYPE_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    FAILURES_FIELD_NUMBER: builtins.int
    WARMUP_SIZE_FIELD_NUMBER: builtins.int
    MODEL_IDENTIFIER_FIELD_NUMBER: builtins.int
    warmup_job_event_type: global___WarmupEventTypeMessage.ValueType
    delay: builtins.int
    failures: builtins.int
    @property
    def warmup_size(self) -> global___WarmupSize: ...
    @property
    def model_identifier(self) -> global___ModelIdentifierMessage: ...
    def __init__(
        self,
        *,
        warmup_job_event_type: global___WarmupEventTypeMessage.ValueType = ...,
        delay: builtins.int = ...,
        failures: builtins.int = ...,
        warmup_size: global___WarmupSize | None = ...,
        model_identifier: global___ModelIdentifierMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_identifier", b"model_identifier", "warmup_size", b"warmup_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delay", b"delay", "failures", b"failures", "model_identifier", b"model_identifier", "warmup_job_event_type", b"warmup_job_event_type", "warmup_size", b"warmup_size"]) -> None: ...

global___WarmupEventMessage = WarmupEventMessage

class WarmupSize(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNIT_FIELD_NUMBER: builtins.int
    NUM_OF_PODS_FIELD_NUMBER: builtins.int
    TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    GPU_RESOURCES_FIELD_NUMBER: builtins.int
    POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    cpu: builtins.float
    memory_amount: builtins.int
    memory_unit: global___MemoryUnit.ValueType
    num_of_pods: builtins.int
    timeout_seconds: builtins.int
    """The timeout for the warmup"""
    @property
    def gpu_resources(self) -> qwak.user_application.common.v0.resources_pb2.GpuResources:
        """Optional GPU resources for batch"""
    @property
    def pod_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.PodComputeResources: ...
    def __init__(
        self,
        *,
        cpu: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_unit: global___MemoryUnit.ValueType = ...,
        num_of_pods: builtins.int = ...,
        timeout_seconds: builtins.int = ...,
        gpu_resources: qwak.user_application.common.v0.resources_pb2.GpuResources | None = ...,
        pod_compute_resources: qwak.user_application.common.v0.resources_pb2.PodComputeResources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gpu_resources", b"gpu_resources", "pod_compute_resources", b"pod_compute_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu", b"cpu", "gpu_resources", b"gpu_resources", "memory_amount", b"memory_amount", "memory_unit", b"memory_unit", "num_of_pods", b"num_of_pods", "pod_compute_resources", b"pod_compute_resources", "timeout_seconds", b"timeout_seconds"]) -> None: ...

global___WarmupSize = WarmupSize

class ModelIdentifierMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    branch_id: builtins.str
    build_id: builtins.str
    user_id: builtins.str
    environment_id: builtins.str
    account_id: builtins.str
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
        user_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "branch_id", b"branch_id", "build_id", b"build_id", "environment_id", b"environment_id", "model_id", b"model_id", "user_id", b"user_id"]) -> None: ...

global___ModelIdentifierMessage = ModelIdentifierMessage

class TaskFailureReason(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FAILURE_REASON_CODE_FIELD_NUMBER: builtins.int
    TASK_FAILURE_REASON_DETAILS_FIELD_NUMBER: builtins.int
    task_failure_reason_code: global___TaskFailureReasonCode.ValueType
    task_failure_reason_details: builtins.str
    def __init__(
        self,
        *,
        task_failure_reason_code: global___TaskFailureReasonCode.ValueType = ...,
        task_failure_reason_details: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["task_failure_reason_code", b"task_failure_reason_code", "task_failure_reason_details", b"task_failure_reason_details"]) -> None: ...

global___TaskFailureReason = TaskFailureReason



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/monitoring/v0/alerting_channel_sync_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.monitoring.v0 import alerting_channel_pb2 as qwak_dot_monitoring_dot_v0_dot_alerting__channel__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/monitoring/v0/alerting_channel_sync_service.proto\x12\x12qwak.monitoring.v0\x1a)qwak/monitoring/v0/alerting_channel.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"d\n)ListAlertingChannelsForEdgeClusterRequest\x12\x37\n\x13sync_channels_since\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"e\n*ListAlertingChannelsForEdgeClusterResponse\x12\x37\n\rsync_response\x18\x01 \x01(\x0b\x32 .qwak.monitoring.v0.SyncResponse\"d\n)ListAlertingChannelsForCoreClusterRequest\x12\x37\n\x13sync_channels_since\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"e\n*ListAlertingChannelsForCoreClusterResponse\x12\x37\n\rsync_response\x18\x01 \x01(\x0b\x32 .qwak.monitoring.v0.SyncResponse2\xe8\x02\n\x1a\x41lertingChannelSyncService\x12\xa3\x01\n\"ListAlertingChannelsForEdgeCluster\x12=.qwak.monitoring.v0.ListAlertingChannelsForEdgeClusterRequest\x1a>.qwak.monitoring.v0.ListAlertingChannelsForEdgeClusterResponse\x12\xa3\x01\n\"ListAlertingChannelsForCoreCluster\x12=.qwak.monitoring.v0.ListAlertingChannelsForCoreClusterRequest\x1a>.qwak.monitoring.v0.ListAlertingChannelsForCoreClusterResponseB2\n\x1d\x63om.qwak.ai.monitoring.api.v0P\x01Z\x0f.;monitoring_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.monitoring.v0.alerting_channel_sync_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.monitoring.api.v0P\001Z\017.;monitoring_v0'
  _globals['_LISTALERTINGCHANNELSFOREDGECLUSTERREQUEST']._serialized_start=154
  _globals['_LISTALERTINGCHANNELSFOREDGECLUSTERREQUEST']._serialized_end=254
  _globals['_LISTALERTINGCHANNELSFOREDGECLUSTERRESPONSE']._serialized_start=256
  _globals['_LISTALERTINGCHANNELSFOREDGECLUSTERRESPONSE']._serialized_end=357
  _globals['_LISTALERTINGCHANNELSFORCORECLUSTERREQUEST']._serialized_start=359
  _globals['_LISTALERTINGCHANNELSFORCORECLUSTERREQUEST']._serialized_end=459
  _globals['_LISTALERTINGCHANNELSFORCORECLUSTERRESPONSE']._serialized_start=461
  _globals['_LISTALERTINGCHANNELSFORCORECLUSTERRESPONSE']._serialized_end=562
  _globals['_ALERTINGCHANNELSYNCSERVICE']._serialized_start=565
  _globals['_ALERTINGCHANNELSYNCSERVICE']._serialized_end=925
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.monitoring.v0.alerting_channel_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ListAlertingChannelsForEdgeClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNC_CHANNELS_SINCE_FIELD_NUMBER: builtins.int
    @property
    def sync_channels_since(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time the channels should be synced from"""
    def __init__(
        self,
        *,
        sync_channels_since: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_channels_since", b"sync_channels_since"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sync_channels_since", b"sync_channels_since"]) -> None: ...

global___ListAlertingChannelsForEdgeClusterRequest = ListAlertingChannelsForEdgeClusterRequest

class ListAlertingChannelsForEdgeClusterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNC_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def sync_response(self) -> qwak.monitoring.v0.alerting_channel_pb2.SyncResponse:
        """what channels to sync or an indicator for up-to-date"""
    def __init__(
        self,
        *,
        sync_response: qwak.monitoring.v0.alerting_channel_pb2.SyncResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_response", b"sync_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sync_response", b"sync_response"]) -> None: ...

global___ListAlertingChannelsForEdgeClusterResponse = ListAlertingChannelsForEdgeClusterResponse

class ListAlertingChannelsForCoreClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNC_CHANNELS_SINCE_FIELD_NUMBER: builtins.int
    @property
    def sync_channels_since(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time the channels should be synced from"""
    def __init__(
        self,
        *,
        sync_channels_since: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_channels_since", b"sync_channels_since"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sync_channels_since", b"sync_channels_since"]) -> None: ...

global___ListAlertingChannelsForCoreClusterRequest = ListAlertingChannelsForCoreClusterRequest

class ListAlertingChannelsForCoreClusterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNC_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def sync_response(self) -> qwak.monitoring.v0.alerting_channel_pb2.SyncResponse:
        """what channels to sync or an indicator for up-to-date"""
    def __init__(
        self,
        *,
        sync_response: qwak.monitoring.v0.alerting_channel_pb2.SyncResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_response", b"sync_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sync_response", b"sync_response"]) -> None: ...

global___ListAlertingChannelsForCoreClusterResponse = ListAlertingChannelsForCoreClusterResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jfml/hosting_gateway/v1/build_upload_url.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.jfml/hosting_gateway/v1/build_upload_url.proto\x12\x17jfml.hosting_gateway.v1\"\xd3\x01\n\x18\x42uildUploadUrlParameters\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x11\n\ttag_value\x18\x03 \x01(\t\x12\x41\n\rartifact_type\x18\x04 \x01(\x0e\x32*.jfml.hosting_gateway.v1.BuildArtifactType\x12$\n\x1ause_cloud_provider_storage\x18\x05 \x01(\x08H\x00\x42\x17\n\x15\x63loud_provider_option*v\n\x11\x42uildArtifactType\x12\x19\n\x15INVALID_ARTIFACT_TYPE\x10\x00\x12\x16\n\x12\x44\x41TA_ARTIFACT_TYPE\x10\x01\x12\x16\n\x12\x46ILE_ARTIFACT_TYPE\x10\x02\x12\x16\n\x12\x43ODE_ARTIFACT_TYPE\x10\x03\x42\'\n#com.jfrog.ml.hosting_gateway.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jfml.hosting_gateway.v1.build_upload_url_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.jfrog.ml.hosting_gateway.api.v1P\001'
  _globals['_BUILDARTIFACTTYPE']._serialized_start=289
  _globals['_BUILDARTIFACTTYPE']._serialized_end=407
  _globals['_BUILDUPLOADURLPARAMETERS']._serialized_start=76
  _globals['_BUILDUPLOADURLPARAMETERS']._serialized_end=287
# @@protoc_insertion_point(module_scope)



from _qwak_proto.qwak.builds.internal_builds_orchestrator_service_pb2 import (
    BuildInitDetails,
    InternalBuildModelRequest,
    InternalBuildModelResponse,
)
from _qwak_proto.qwak.builds.internal_builds_orchestrator_service_pb2_grpc import (
    InternalBuildsOrchestratorServiceServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class InternalBuildOrchestratorServiceMock(InternalBuildsOrchestratorServiceServicer):
    def __init__(self):
        super(InternalBuildOrchestratorServiceMock, self).__init__()
        self._builds_requests: dict[str:BuildInitDetails] = {}

    def BuildModel(self, request: InternalBuildModelRequest, context):
        """Build a serving model image"""
        try:
            self._builds_requests[
                request.build_init_details.build_spec.build_properties.build_id
            ] = request.build_init_details
            return InternalBuildModelResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)



import os
import pickle  # nosec B403
import tempfile

from qwak.model.base import QwakModel

from .artifact_logger import load_file, log_file

MODEL_TAG = "qwak_model"
FILE_NAME = "qwak_model.pkl"


def log_model(build_id: str, model: QwakModel) -> None:
    with open(FILE_NAME, "wb") as handle:
        pickle.dump(model, handle, protocol=pickle.HIGHEST_PROTOCOL)

    log_file(from_path=FILE_NAME, tag=MODEL_TAG, build_id=build_id, model_id=None)


def load_model(model_id: str, build_id: str) -> QwakModel:
    with tempfile.TemporaryDirectory() as td:
        temp_file_path = os.path.join(td, FILE_NAME)
        load_file(
            to_path=temp_file_path, tag=MODEL_TAG, build_id=build_id, model_id=model_id
        )

        with open(temp_file_path, "rb") as handle:
            model = pickle.load(handle)  # nosec B301

    return model



import grpc
from qwak.exceptions import QwakException


def grpc_try_catch_wrapper(exception_message):
    def decorator(function):
        def _inner_wrapper(*args, **kwargs):
            try:
                return function(*args, **kwargs)
            except grpc.RpcError as e:
                raise QwakException(exception_message + f". Error is: {e}.")

        return _inner_wrapper

    return decorator



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/feature_store_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.external import redis_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_external_dot_redis__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGqwak/administration/runtime_configuration/v0/feature_store_config.proto\x12\x41qwak.administration.runtime_configuration.v0.feature_store_config\x1aHqwak/administration/runtime_configuration/v0/external/redis_config.proto\"\x9d\x01\n\x19\x46\x65\x61tureStoreConfiguration\x12v\n\x07\x65nabled\x18\x02 \x01(\x0b\x32\x63.qwak.administration.runtime_configuration.v0.feature_store_config.EnabledFeatureStoreConfigurationH\x00\x42\x08\n\x06toggle\"\x97\x01\n EnabledFeatureStoreConfiguration\x12s\n\x14online_feature_store\x18\x01 \x01(\x0b\x32U.qwak.administration.runtime_configuration.v0.feature_store_config.OnlineFeatureStore\"\x93\x01\n\x12OnlineFeatureStore\x12u\n\x13redis_configuration\x18\x01 \x01(\x0b\x32V.qwak.administration.runtime_configuration.v0.external.redis_config.RedisConfigurationH\x00\x42\x06\n\x04typeB\xe1\x01\n:com.jfrog.ml.runtime_configuration.v0.feature_store_configP\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.feature_store_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n:com.jfrog.ml.runtime_configuration.v0.feature_store_configP\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _globals['_FEATURESTORECONFIGURATION']._serialized_start=217
  _globals['_FEATURESTORECONFIGURATION']._serialized_end=374
  _globals['_ENABLEDFEATURESTORECONFIGURATION']._serialized_start=377
  _globals['_ENABLEDFEATURESTORECONFIGURATION']._serialized_end=528
  _globals['_ONLINEFEATURESTORE']._serialized_start=531
  _globals['_ONLINEFEATURESTORE']._serialized_end=678
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass, field

from _qwak_proto.qwak.data_versioning.data_versioning_pb2 import (
    DataTagSpec as DataTagSpecProto,
)


@dataclass
class DataTag:
    model_id: str = field(default=None)
    build_id: str = field(default=None)
    tag: str = field(default=None)
    extension_type: str = field(default=None)
    environment_id: str = field(default=None)

    @staticmethod
    def from_proto(data_versioning_spec_proto: DataTagSpecProto):
        return DataTag(
            model_id=data_versioning_spec_proto.model_id,
            build_id=data_versioning_spec_proto.build_id,
            tag=data_versioning_spec_proto.tag,
            extension_type=data_versioning_spec_proto.extension_type,
            environment_id=data_versioning_spec_proto.environment_id,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/v1/common/source_code/source_code.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.v1.common.jfrog_artifact import jfrog_artifact_pb2 as qwak_dot_feature__store_dot_v1_dot_common_dot_jfrog__artifact_dot_jfrog__artifact__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:qwak/feature_store/v1/common/source_code/source_code.proto\x12(qwak.feature.store.v1.common.source_code\x1a@qwak/feature_store/v1/common/jfrog_artifact/jfrog_artifact.proto\"`\n\x0eSourceCodeSpec\x12N\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32<.qwak.feature.store.v1.common.source_code.SourceCodeArtifact\"k\n\x12SourceCodeArtifact\x12M\n\x0czip_artifact\x18\x01 \x01(\x0b\x32\x35.qwak.feature.store.v1.common.source_code.ZipArtifactH\x00\x42\x06\n\x04type\"\x98\x01\n\x0bZipArtifact\x12\x0e\n\x04path\x18\x01 \x01(\tH\x00\x12Y\n\x13jfrog_artifact_path\x18\x03 \x01(\x0b\x32:.qwak.feature.store.v1.common.jfrog_artifact.JfrogArtifactH\x00\x12\x11\n\tmain_file\x18\x02 \x01(\tB\x0b\n\tpath_typeBg\n/com.qwak.ai.feature.store.v1.common.source_codeP\x01Z2qwak/featurestore/v1/common/source_code;sourcecodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.v1.common.source_code.source_code_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n/com.qwak.ai.feature.store.v1.common.source_codeP\001Z2qwak/featurestore/v1/common/source_code;sourcecode'
  _globals['_SOURCECODESPEC']._serialized_start=170
  _globals['_SOURCECODESPEC']._serialized_end=266
  _globals['_SOURCECODEARTIFACT']._serialized_start=268
  _globals['_SOURCECODEARTIFACT']._serialized_end=375
  _globals['_ZIPARTIFACT']._serialized_start=378
  _globals['_ZIPARTIFACT']._serialized_end=530
# @@protoc_insertion_point(module_scope)



from typing import Any


class BaseInputAdapter:
    """
    BaseInputAdapter is an abstraction layer between user defined API callback function
    and prediction request input in a variety of different forms.
    """

    def __init__(self, **kwargs):
        """
        BaseInputAdapter constructor - accept all keyword arguments as configuration (only in runtime)
        :param kwargs:
        """
        pass

    def extract_user_func_args(self, data: Any) -> Any:
        """
        Extract args that user API function is expecting from Inference
        """
        raise NotImplementedError()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.administration.account.v1 import preferences_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_preferences__pb2
from _qwak_proto.qwak.administration.account.v1 import terms_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_terms__pb2
from _qwak_proto.qwak.administration.account.v1 import jfrog_tenant_details_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_jfrog__tenant__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/administration/account/v1/account.proto\x12\x1eqwak.administration.account.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x30qwak/administration/account/v1/preferences.proto\x1a*qwak/administration/account/v1/terms.proto\x1a\x39qwak/administration/account/v1/jfrog_tenant_details.proto\"\xc9\x04\n\x07\x41\x63\x63ount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x45\n\x06status\x18\x04 \x01(\x0e\x32\x35.qwak.administration.account.v1.AccountActivityStatus\x12\x44\n\x0bpreferences\x18\x07 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x1e\n\x16\x64\x65\x66\x61ult_environment_id\x18\x08 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x04type\x18\t \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\n \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\x12I\n\x0e\x61\x63\x63\x65pted_terms\x18\x0b \x01(\x0b\x32\x31.qwak.administration.account.AccountAcceptedTerms\x12P\n\x14jfrog_tenant_details\x18\x0c \x01(\x0b\x32\x32.qwak.administration.account.v1.JfrogTenantDetails\"c\n\x11ListAccountFilter\x12N\n\x0f\x61\x63tivity_status\x18\x01 \x01(\x0e\x32\x35.qwak.administration.account.v1.AccountActivityStatus\"_\n\x12\x41utoBindingAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12=\n\x04rule\x18\x02 \x01(\x0b\x32/.qwak.administration.account.v1.AutoBindingRule\")\n\x0f\x41utoBindingRule\x12\x16\n\x0e\x65mail_hostname\x18\x01 \x01(\t\"\xb1\x02\n\x0c\x41\x63\x63ountBrief\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x19\n\x0fjfrog_tenant_id\x18\x02 \x01(\tH\x00\x12\x1b\n\x0f\x65nvironment_ids\x18\x03 \x03(\tB\x02\x18\x01\x12\x16\n\x0e\x64\x65\x66\x61ult_env_id\x18\x04 \x01(\t\x12L\n\x12\x65nvironment_briefs\x18\x05 \x03(\x0b\x32\x30.qwak.administration.account.v1.EnvironmentBrief\x12\x41\n\x0bjpd_details\x18\x06 \x01(\x0b\x32*.qwak.administration.account.v1.JPDDetailsH\x01\x42\x14\n\x12optional_tenant_idB\x16\n\x14optional_jpd_details\"B\n\x10\x45nvironmentBrief\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x16\n\x0estorage_bucket\x18\x02 \x01(\t*k\n\x15\x41\x63\x63ountActivityStatus\x12\x1a\n\x16\x41\x43\x43OUNT_STATUS_INVALID\x10\x00\x12\x19\n\x15\x41\x43\x43OUNT_STATUS_ACTIVE\x10\x01\x12\x1b\n\x17\x41\x43\x43OUNT_STATUS_DISABLED\x10\x02*=\n\x0b\x41\x63\x63ountType\x12\x18\n\x14\x41\x43\x43OUNT_TYPE_INVALID\x10\x00\x12\n\n\x06HYBRID\x10\x01\x12\x08\n\x04SAAS\x10\x02*L\n\x0b\x41\x63\x63ountTier\x12\x18\n\x14\x41\x43\x43OUNT_TIER_INVALID\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\r\n\tVALIDATED\x10\x02\x12\n\n\x06PAYING\x10\x03\x42\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.account.v1.account_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _ACCOUNTBRIEF.fields_by_name['environment_ids']._options = None
  _ACCOUNTBRIEF.fields_by_name['environment_ids']._serialized_options = b'\030\001'
  _globals['_ACCOUNTACTIVITYSTATUS']._serialized_start=1471
  _globals['_ACCOUNTACTIVITYSTATUS']._serialized_end=1578
  _globals['_ACCOUNTTYPE']._serialized_start=1580
  _globals['_ACCOUNTTYPE']._serialized_end=1641
  _globals['_ACCOUNTTIER']._serialized_start=1643
  _globals['_ACCOUNTTIER']._serialized_end=1719
  _globals['_ACCOUNT']._serialized_start=267
  _globals['_ACCOUNT']._serialized_end=852
  _globals['_LISTACCOUNTFILTER']._serialized_start=854
  _globals['_LISTACCOUNTFILTER']._serialized_end=953
  _globals['_AUTOBINDINGACCOUNT']._serialized_start=955
  _globals['_AUTOBINDINGACCOUNT']._serialized_end=1050
  _globals['_AUTOBINDINGRULE']._serialized_start=1052
  _globals['_AUTOBINDINGRULE']._serialized_end=1093
  _globals['_ACCOUNTBRIEF']._serialized_start=1096
  _globals['_ACCOUNTBRIEF']._serialized_end=1401
  _globals['_ENVIRONMENTBRIEF']._serialized_start=1403
  _globals['_ENVIRONMENTBRIEF']._serialized_end=1469
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jfml/hosting_gateway/v1/hosting_gateway_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from jfml.hosting_gateway.v1 import build_upload_url_pb2 as jfml_dot_hosting__gateway_dot_v1_dot_build__upload__url__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5jfml/hosting_gateway/v1/hosting_gateway_service.proto\x12\x17jfml.hosting_gateway.v1\x1a.jfml/hosting_gateway/v1/build_upload_url.proto\"g\n\"GetBuildVersioningUploadURLRequest\x12\x41\n\x06params\x18\x01 \x01(\x0b\x32\x31.jfml.hosting_gateway.v1.BuildUploadUrlParameters\"9\n#GetBuildVersioningUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t2\xb2\x01\n\x15HostingGatewayService\x12\x98\x01\n\x1bGetBuildVersioningUploadURL\x12;.jfml.hosting_gateway.v1.GetBuildVersioningUploadURLRequest\x1a<.jfml.hosting_gateway.v1.GetBuildVersioningUploadURLResponseB\'\n#com.jfrog.ml.hosting_gateway.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jfml.hosting_gateway.v1.hosting_gateway_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.jfrog.ml.hosting_gateway.api.v1P\001'
  _globals['_GETBUILDVERSIONINGUPLOADURLREQUEST']._serialized_start=130
  _globals['_GETBUILDVERSIONINGUPLOADURLREQUEST']._serialized_end=233
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE']._serialized_start=235
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE']._serialized_end=292
  _globals['_HOSTINGGATEWAYSERVICE']._serialized_start=295
  _globals['_HOSTINGGATEWAYSERVICE']._serialized_end=473
# @@protoc_insertion_point(module_scope)



from ._authentication_utils import (
    get_credentials,
    get_frogml_configuration,
    parse_cli_config_server,
    read_jfrog_cli_config,
    get_encrypted_password,
    save_auth_config,
    get_list_of_servers_from_config,
    read_frogml_config,
)
from ._login_checks_utils import (
    login_input_checks,
    is_login_without_params,
    is_username_password_login,
    is_access_token_login,
    is_anonymous_login,
)
